@@ -2,37 +2,48 @@
 import asyncio
 from enum import Enum
 import logging
+from typing import TYPE_CHECKING, Awaitable, Callable, Dict, Optional, Tuple, Union
 
 from xknx.remote_value import RemoteValue
 
-DEFAULT_UPDATE_INTERVAL = 60
-MAX_UPDATE_INTERVAL = 1440
+if TYPE_CHECKING:
+    from xknx.xknx import XKNX
+
 
 logger = logging.getLogger("xknx.state_updater")
 
+DEFAULT_UPDATE_INTERVAL = 60
+MAX_UPDATE_INTERVAL = 1440
+
 
 class StateUpdater:
     """Class for keeping the states of RemoteValues up to date."""
 
-    def __init__(self, xknx, parallel_reads: int = 2):
+    def __init__(self, xknx: "XKNX", parallel_reads: int = 2):
         """Initialize StateUpdater class."""
         self.xknx = xknx
         self.started = False
-        self._workers = {}
+        self._workers: Dict[int, _StateTracker] = {}
         self._semaphore = asyncio.Semaphore(value=parallel_reads)
 
-    def register_remote_value(self, remote_value: RemoteValue, tracker_options=True):
+    def register_remote_value(
+        self,
+        remote_value: RemoteValue,
+        tracker_options: Union[bool, int, float, str] = True,
+    ) -> None:
         """Register a RemoteValue to initialize its state and/or track for expiration."""
 
-        def parse_tracker_options(tracker_options):
+        def parse_tracker_options(
+            tracker_options: Union[bool, int, float, str]
+        ) -> Tuple[StateTrackerType, Union[int, float]]:
             """Parse tracker type and expiration time."""
             tracker_type = StateTrackerType.EXPIRE
-            update_interval = DEFAULT_UPDATE_INTERVAL
+            update_interval: Union[int, float] = DEFAULT_UPDATE_INTERVAL
 
             if isinstance(tracker_options, bool):
                 # `True` would be overwritten by the check for `int`
                 return (tracker_type, update_interval)
-            if isinstance(tracker_options, int):
+            if isinstance(tracker_options, (int, float)):
                 update_interval = tracker_options
             elif isinstance(tracker_options, str):
                 _options = tracker_options.split()
@@ -56,15 +67,7 @@ class StateUpdater:
                         update_interval = int(_options[1])
                 except IndexError:
                     pass  # No time given (no _options[1])
-            else:
-                logger.warning(
-                    'Could not parse StateUpdater tracker_options type %s "%s" for %s. Using default %s %s minutes.',
-                    type(tracker_options),
-                    tracker_options,
-                    remote_value,
-                    tracker_type,
-                    update_interval,
-                )
+
             if update_interval > MAX_UPDATE_INTERVAL:
                 logger.warning(
                     "StateUpdater interval of %s to long for %s. Using maximum of %s minutes (1 day)",
@@ -75,7 +78,7 @@ class StateUpdater:
                 update_interval = MAX_UPDATE_INTERVAL
             return (tracker_type, update_interval)
 
-        async def read_state_mutex():
+        async def read_state_mutex() -> None:
             """Schedule to read the state from the KNX bus - one at a time."""
             async with self._semaphore:
                 # wait until there is nothing else to send to the bus
@@ -92,9 +95,9 @@ class StateUpdater:
 
         tracker_type, update_interval = parse_tracker_options(tracker_options)
         tracker = _StateTracker(
+            read_state_awaitable=read_state_mutex,
             tracker_type=tracker_type,
             interval_min=update_interval,
-            read_state_awaitable=read_state_mutex,
         )
         self._workers[id(remote_value)] = tracker
 
@@ -107,23 +110,23 @@ class StateUpdater:
         if self.started:
             tracker.start()
 
-    def unregister_remote_value(self, remote_value: RemoteValue):
+    def unregister_remote_value(self, remote_value: RemoteValue) -> None:
         """Unregister a RemoteValue from StateUpdater."""
         self._workers.pop(id(remote_value)).stop()
 
-    def update_received(self, remote_value: RemoteValue):
+    def update_received(self, remote_value: RemoteValue) -> None:
         """Reset the timer when a state update was received."""
         if self.started and id(remote_value) in self._workers:
             self._workers[id(remote_value)].update_received()
 
-    def start(self):
+    def start(self) -> None:
         """Start StateUpdater. Initialize states."""
         logger.debug("StateUpdater initializing values")
         self.started = True
         for worker in self._workers.values():
             worker.start()
 
-    def stop(self):
+    def stop(self) -> None:
         """Stop StateUpdater."""
         logger.debug("StateUpdater stopping")
         self.started = False
@@ -145,45 +148,45 @@ class _StateTracker:
     # pylint: disable=too-many-instance-attributes
     def __init__(
         self,
+        read_state_awaitable: Callable[[], Awaitable[None]],
         tracker_type: StateTrackerType = StateTrackerType.EXPIRE,
-        interval_min: int = 60,
-        read_state_awaitable=None,
+        interval_min: float = 60,
     ):
         """Initialize StateTracker class."""
         # pylint: disable=too-many-arguments
         self.tracker_type = tracker_type
         self.update_interval = interval_min * 60
         self._read_state = read_state_awaitable
-        self._task = None
+        self._task: Optional[asyncio.Task[None]] = None
 
-    def start(self):
+    def start(self) -> None:
         """Start StateTracker - read state on call."""
         self.stop()
         self._task = asyncio.create_task(self._start_init())
 
-    async def _start_init(self):
+    async def _start_init(self) -> None:
         """Initialize state, start update loop if appropriate."""
         await self._read_state()
         if self.tracker_type is not StateTrackerType.INIT:
             self.reset()
 
-    def reset(self):
+    def reset(self) -> None:
         """Start / Restart StateTracker timer - wait for value to expire."""
         self.stop()
         self._task = asyncio.create_task(self._update_loop())
 
-    def stop(self):
+    def stop(self) -> None:
         """Stop StateTracker."""
         if self._task:
             self._task.cancel()
             self._task = None
 
-    def update_received(self):
+    def update_received(self) -> None:
         """Reset the timer if a telegram was received for a "expire" typed StateUpdater."""
         if self.tracker_type == StateTrackerType.EXPIRE:
             self.reset()
 
-    async def _update_loop(self):
+    async def _update_loop(self) -> None:
         """Wait for the update_interval to expire. Endless loop for updating states."""
         # for StateUpdaterType.EXPIRE:
         #   on successfull read the while loop gets canceled when the callback calls update_received()
