@@ -1,9 +1,15 @@
 """Module for managing a notification via KNX."""
 import logging
+from typing import TYPE_CHECKING, Any, Iterator, Optional
 
 from xknx.remote_value import RemoteValueString
 
-from .device import Device
+from .device import Device, DeviceCallbackType
+
+if TYPE_CHECKING:
+    from xknx.telegram import Telegram
+    from xknx.telegram.address import GroupAddressableType
+    from xknx.xknx import XKNX
 
 logger = logging.getLogger("xknx.log")
 
@@ -13,11 +19,11 @@ class Notification(Device):
 
     def __init__(
         self,
-        xknx,
-        name,
-        group_address=None,
-        group_address_state=None,
-        device_updated_cb=None,
+        xknx: "XKNX",
+        name: str,
+        group_address: Optional["GroupAddressableType"] = None,
+        group_address_state: Optional["GroupAddressableType"] = None,
+        device_updated_cb: Optional[DeviceCallbackType] = None,
     ):
         """Initialize notification class."""
         # pylint: disable=too-many-arguments
@@ -32,12 +38,12 @@ class Notification(Device):
             after_update_cb=self.after_update,
         )
 
-    def _iter_remote_values(self):
+    def _iter_remote_values(self) -> Iterator[RemoteValueString]:
         """Iterate the devices RemoteValue classes."""
         yield self._message
 
     @classmethod
-    def from_config(cls, xknx, name, config):
+    def from_config(cls, xknx: "XKNX", name: str, config: Any) -> "Notification":
         """Initialize object from configuration structure."""
         group_address = config.get("group_address")
         group_address_state = config.get("group_address_state")
@@ -50,20 +56,20 @@ class Notification(Device):
         )
 
     @property
-    def message(self):
+    def message(self) -> Optional[str]:
         """Return the current message."""
-        return self._message.value
+        return self._message.value  # type: ignore
 
-    async def set(self, message):
+    async def set(self, message: str) -> None:
         """Set message."""
         cropped_message = message[:14]
         await self._message.set(cropped_message)
 
-    async def process_group_write(self, telegram):
+    async def process_group_write(self, telegram: "Telegram") -> None:
         """Process incoming and outgoing GROUP WRITE telegram."""
         await self._message.process(telegram)
 
-    async def do(self, action):
+    async def do(self, action: str) -> None:
         """Execute 'do' commands."""
         if action.startswith("message:"):
             await self.set(action[8:])
@@ -72,7 +78,7 @@ class Notification(Device):
                 "Could not understand action %s for device %s", action, self.get_name()
             )
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return object as readable string."""
         return '<Notification name="{}" message="{}" />'.format(
             self.name, self._message.group_addr_str()
