@@ -1,16 +1,31 @@
 """Abstraction to send ConnectonStateRequest and wait for ConnectionStateResponse."""
+from typing import TYPE_CHECKING
+
 from xknx.knxip import HPAI, ConnectionStateRequest, ConnectionStateResponse, KNXIPFrame
 
+from .const import CONNECTIONSTATE_REQUEST_TIMEOUT
 from .request_response import RequestResponse
 
+if TYPE_CHECKING:
+    from xknx.xknx import XKNX
+
+    from .udp_client import UDPClient
+
 
 class ConnectionState(RequestResponse):
     """Class to send ConnectonStateRequest and wait for ConnectionStateResponse."""
 
-    def __init__(self, xknx, udp_client, communication_channel_id):
+    def __init__(
+        self, xknx: "XKNX", udp_client: "UDPClient", communication_channel_id: int
+    ):
         """Initialize ConnectionState class."""
         self.udp_client = udp_client
-        super().__init__(xknx, self.udp_client, ConnectionStateResponse)
+        super().__init__(
+            xknx,
+            self.udp_client,
+            ConnectionStateResponse,
+            timeout_in_seconds=CONNECTIONSTATE_REQUEST_TIMEOUT,
+        )
         self.communication_channel_id = communication_channel_id
 
     def create_knxipframe(self) -> KNXIPFrame:
