@@ -6,6 +6,7 @@ from enum import Enum
 class KNXIPServiceType(Enum):
     """Enum class for KNX/IP Service Types."""
 
+    # 0x02 Core services
     SEARCH_REQUEST = 0x0201
     SEARCH_RESPONSE = 0x0202
     DESCRIPTION_REQUEST = 0x0203
@@ -16,13 +17,37 @@ class KNXIPServiceType(Enum):
     CONNECTIONSTATE_RESPONSE = 0x0208
     DISCONNECT_REQUEST = 0x0209
     DISCONNECT_RESPONSE = 0x020A
+    SEARCH_REQUEST_EXTENDED = 0x020B
+    SEARCH_RESPONSE_EXTENDED = 0x020C
+    # 0x03 Device Management services
     DEVICE_CONFIGURATION_REQUEST = 0x0310
-    DEVICE_CONFIGURATION_ACK = 0x0111
+    DEVICE_CONFIGURATION_ACK = 0x0311
+    # 0x04 Tunneling services
     TUNNELLING_REQUEST = 0x0420
     TUNNELLING_ACK = 0x0421
+    TUNNELLING_FEATURE_GET = 0x0422
+    TUNNELLING_FEATURE_RESPONSE = 0x0423
+    TUNNELLING_FEATURE_SET = 0x0424
+    TUNNELLING_FEATURE_INFO = 0x0425
+    # 0x05 Routing services
     ROUTING_INDICATION = 0x0530
     ROUTING_LOST_MESSAGE = 0x0531
-    UNKNOWN = 0x0000
+    ROUTING_BUSY = 0x0532
+    ROUTING_SYSTEM_BROADCAST = 0x0533
+    # 0x06 Remote Logging services
+    # 0x07 Remote Configuration and Diagnosis services
+    REMOTE_DIAG_REQUEST = 0x0740
+    REMOTE_DIAG_RESPONSE = 0x0741
+    REMOTE_CONFIG_REQUEST = 0x0742
+    REMOTE_RESET_REQUEST = 0x0743
+    # 0x08 Object Server services
+    # 0x09 Security services
+    SECURE_WRAPPER = 0x0950
+    SECURE_SESSION_REQUEST = 0x0951
+    SECURE_SESSION_RESPONSE = 0x0952
+    SECURE_SESSION_AUTHENTICATE = 0x0953
+    SECURE_SESSION_STATUS = 0x0954
+    SECURE_TIMER_NOTIFY = 0x0955
 
 
 class CEMIMessageCode(Enum):
@@ -49,14 +74,6 @@ class CEMIMessageCode(Enum):
     L_RAW_CON = 0x2F
 
 
-class APCICommand(Enum):
-    """Enum class for KNX/IP APCI Commands."""
-
-    GROUP_READ = 0x00
-    GROUP_WRITE = 0x80
-    GROUP_RESPONSE = 0x40
-
-
 class CEMIFlags:
     """Enum class for KNX/IP CEMI Flags."""
 
