@@ -4,6 +4,7 @@ Module for Serialization and Deserialization of a KNX Tunnelling Request informa
 Tunnelling requests are used to transmit a KNX telegram within an existing KNX tunnel connection.
 """
 import logging
+from typing import TYPE_CHECKING, List, Optional
 
 from xknx.exceptions import CouldNotParseKNXIP, UnsupportedCEMIMessage
 
@@ -11,6 +12,9 @@ from .body import KNXIPBody
 from .cemi_frame import CEMIFrame, CEMIMessageCode
 from .knxip_enum import KNXIPServiceType
 
+if TYPE_CHECKING:
+    from xknx.xknx import XKNX
+
 logger = logging.getLogger("xknx.log")
 
 
@@ -25,30 +29,32 @@ class TunnellingRequest(KNXIPBody):
 
     def __init__(
         self,
-        xknx,
+        xknx: "XKNX",
         communication_channel_id: int = 1,
         sequence_counter: int = 0,
-        cemi: CEMIFrame = None,
+        cemi: Optional[CEMIFrame] = None,
     ):
         """Initialize TunnellingRequest object."""
         super().__init__(xknx)
 
         self.communication_channel_id = communication_channel_id
         self.sequence_counter = sequence_counter
-        self.cemi = (
+        self.cemi: Optional[CEMIFrame] = (
             cemi
             if cemi is not None
             else CEMIFrame(xknx, code=CEMIMessageCode.L_Data_REQ)
         )
 
-    def calculated_length(self):
+    def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
+        assert self.cemi is not None
         return TunnellingRequest.HEADER_LENGTH + self.cemi.calculated_length()
 
-    def from_knx(self, raw):
+    def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
+        assert self.cemi is not None
 
-        def header_from_knx(header):
+        def header_from_knx(header: bytes) -> int:
             """Parse header bytes."""
             if header[0] != TunnellingRequest.HEADER_LENGTH:
                 raise CouldNotParseKNXIP("connection header wrong length")
@@ -68,10 +74,12 @@ class TunnellingRequest(KNXIPBody):
             return len(raw)
         return pos
 
-    def to_knx(self):
+    def to_knx(self) -> List[int]:
         """Serialize to KNX/IP raw data."""
+        if self.cemi is None:
+            raise CouldNotParseKNXIP("No CEMIFrame defined.")
 
-        def header_to_knx():
+        def header_to_knx() -> List[int]:
             """Serialize header."""
             cri = []
             cri.append(TunnellingRequest.HEADER_LENGTH)
@@ -85,7 +93,7 @@ class TunnellingRequest(KNXIPBody):
         data.extend(self.cemi.to_knx())
         return data
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return object as readable string."""
         return (
             '<TunnellingRequest communication_channel_id="{}" '
