@@ -79,10 +79,10 @@ class RemoteValueStep(RemoteValue):
             feature_name=self.feature_name,
         )
 
-    async def increase(self):
+    async def increase(self) -> None:
         """Increase value."""
         await self.set(self.Direction.INCREASE)
 
-    async def decrease(self):
+    async def decrease(self) -> None:
         """Decrease the value."""
         await self.set(self.Direction.DECREASE)
